﻿using System.Security.Authentication;
using IdentityModel;
using XF.Domain.Authentications;
using XF.Domain.Dependency;
using XF.Utility.AppIdentityModel;

namespace Hotline.Api.Token
{
    public class DefaultSessionContext : ISessionContext, IScopeDependency
    {
        public DefaultSessionContext(IHttpContextAccessor httpContextAccessor)
        {
            var httpContext = httpContextAccessor.HttpContext;
            if (httpContext is null)
                throw new ArgumentNullException(nameof(httpContext));

            var user = httpContext.User;
            UserId = user.FindFirstValue(JwtClaimTypes.Subject);
            UserName = user.FindFirstValue(AppClaimTypes.UserDisplayName);
            Phone = user.FindFirstValue(JwtClaimTypes.PhoneNumber);
            Roles = user.Claims.Where(d => d.Type == JwtClaimTypes.Role).Select(d => d.Value).ToArray();
        }

        /// <summary>
        /// Id of current tenant or null for host
        /// </summary>
        public string? UserId { get; }

        /// <summary>
        /// Id of current user or throw Exception for guest
        /// </summary>
        /// <exception cref="AuthenticationException"></exception>
        public string RequiredUserId => UserId ?? throw new ArgumentException();

        public string? UserName { get; }

        public string? Phone { get; }

        /// <summary>
        /// Roles
        /// </summary>
        public string[] Roles { get; }
    }
}
