﻿// Copyright (c) 2018 Jon P Smith, GitHub: JonPSmith, web: http://www.thereformedprogrammer.net/
// Licensed under MIT license. See License.txt in the project root for license information.

using Npgsql.TypeHandlers.NetworkHandlers;
using System.ComponentModel.DataAnnotations;

namespace Hotline.Permissions
{
    public enum EPermission
    {
        NotSet = 0, //error condition

        //Here is an example of very detailed control over something
        /// <summary>
        /// 首页
        /// </summary>
        [Display(GroupName ="首页",Name ="首页",Description ="首页")]
        Home = 000000,

        #region 系统管理相关接口（100）

        /// <summary>
        /// 系统管理
        /// </summary>
        [Display(GroupName = "系统管理", Name = "系统管理", Description = "系统管理")]
        SystemManage = 100000,

        /// <summary>
        /// 机构用户
        /// </summary>
        [Display(GroupName ="系统管理",Name ="机构用户",Description ="机构用户")]
        UserManage = 100100,
        #region 用户管理
        /// <summary>
        /// 分页查询用户
        /// </summary>
        [Display(GroupName = "用户管理", Name = "分页查询用户", Description = "分页查询用户")]
        QueryPagedUser = 100101,
        /// <summary>
        /// 新增用户
        /// </summary>
        [Display(GroupName = "用户管理",Name ="新增用户",Description ="新增用户")]
        AddUser = 100102,
        /// <summary>
        /// 更新用户
        /// </summary>
        [Display(GroupName = "用户管理", Name = "更新用户", Description = "更新用户")]
        UpdateUser = 100103,
        /// <summary>
        /// 删除用户
        /// </summary>
        [Display(GroupName = "用户管理", Name = "删除用户", Description = "删除用户")]
        RemoveUser = 100104,
        /// <summary>
        /// 设置用户角色
        /// </summary>
        [Display(GroupName = "用户管理", Name ="设置用户角色",Description ="设置用户角色")]
        SetUserRoles = 100105,
        /// <summary>
        /// 分页查询用户角色
        /// </summary>
        [Display(GroupName = "用户管理",Name ="分页查询用户角色",Description ="分页查询用户角色")]
        GetUserRoles = 100106,
        #endregion
        #region 角色管理
        /// <summary>
        /// 分页查询角色
        /// </summary>
        [Display(GroupName = "角色管理", Name = "分页查询角色", Description = "分页查询角色")]
        QueryPagedRole = 100200,
        /// <summary>
        /// 新增角色
        /// </summary>
        [Display(GroupName = "角色管理", Name = "新增角色", Description = "新增角色")]
        AddRole = 100201,
        /// <summary>
        /// 删除角色
        /// </summary>
        [Display(GroupName = "角色管理", Name = "删除角色", Description = "删除角色")]
        RemoveRole = 100202,
        /// <summary>
        /// 更新角色
        /// </summary>
        [Display(GroupName = "角色管理", Name = "更新角色", Description = "更新角色")]
        UpdateRole = 100203,
        #region 应用权限管理
        /// <summary>
        /// 分配权限
        /// </summary>
        [Display(GroupName ="角色管理",Name ="分配权限",Description ="分配权限")]
        AllocationAuthority = 100204,
        /// <summary>
        /// 获取角色权限
        /// </summary>
        [Display(GroupName ="角色管理",Name ="获取角色权限",Description ="获取角色权限")]
        GetAuthority = 100205,

        #endregion
        #region 数据权限管理
        /// <summary>
        /// 新增数据权限
        /// </summary>
        [Display(GroupName = "角色管理",Name ="新增数据权限",Description ="新增数据权限")]
        AddDataAuthority = 100206,
        /// <summary>
        /// 修改数据权限
        /// </summary>
        [Display(GroupName = "角色管理",Name="修改数据权限",Description ="修改数据权限")]
        UpdateDataAuthority = 100207,
        /// <summary>
        /// 删除数据权限
        /// </summary>
        [Display(GroupName ="角色管理",Name ="删除数据权限",Description ="删除数据权限")]
        RemoveDataAuthority = 100208,
        /// <summary>
        /// 获取数据权限
        /// </summary>
        [Display(GroupName ="角色管理",Name ="获取数据权限",Description ="获取数据权限")]
        GetDataAuthorityByRole = 100209,
        #endregion
        #endregion
        #region 系统参数

        /// <summary>
        /// 获取系统参数列表
        /// </summary>
        [Display(GroupName = "系统设置", Name = "获取系统参数列表", Description = "获取系统参数列表")]
        GetSysSettingsAsync = 100300,
        /// <summary>
        /// 更新设置
        /// </summary>
        [Display(GroupName = "系统设置", Name = "更新设置", Description = "更新设置")]
        ModifySettings = 100301,

        #endregion
        #region 菜单管理
        /// <summary>
        /// 菜单管理
        /// </summary>
        [Display(GroupName = "系统设置",Name = "菜单管理",Description ="菜单管理")]
        GetMenuJson = 100400,
        /// <summary>
        /// 新增菜单
        /// </summary>
        [Display(GroupName ="系统设置",Name ="新增菜单",Description ="新增菜单")]
        AddMenu = 100401,
        /// <summary>
        /// 修改菜单
        /// </summary>
        [Display(GroupName ="系统设置",Name ="修改菜单",Description ="修改菜单")]
        UpdateMenu = 100402,
        /// <summary>
        /// 删除菜单
        /// </summary>
        [Display(GroupName ="系统设置",Name ="删除菜单",Description ="删除菜单")]
        RemoveMenu = 100403,
        /// <summary>
        /// 获取菜单对象
        /// </summary>
        [Display(GroupName ="系统设置",Name ="获取菜单对象",Description ="获取菜单对象")]
        GetMenu = 100408,
        #endregion
        #region 按钮管理
        /// <summary>
        /// 获取菜单按钮
        /// </summary>
        [Display(GroupName ="系统设置",Name ="获取菜单按钮",Description ="获取菜单按钮")]
        GetButtonByMenu = 100404,
        /// <summary>
        /// 新增按钮
        /// </summary>
        [Display(GroupName ="系统设置",Name ="新增按钮",Description ="新增按钮")]
        AddButton = 100405,
        /// <summary>
        /// 编辑按钮
        /// </summary>
        [Display(GroupName ="系统设置",Name ="编辑按钮",Description ="编辑按钮")]
        UpdateButton = 100406,
        /// <summary>
        /// 删除按钮
        /// </summary>
        [Display(GroupName ="系统设置",Name ="删除按钮",Description ="删除按钮")]
        RemoveButton = 100407,
        /// <summary>
        /// 获取按钮对象
        /// </summary>
        [Display(GroupName ="系统设置",Name ="获取按钮对象",Description ="获取按钮对象")]
        GetButton = 100409,
        #endregion
        #region 组织架构管理
        /// <summary>
        /// 组织架构树形列表
        /// </summary>
        [Display(GroupName ="系统设置",Name ="组织架构树形列表",Description ="组织架构树形列表")]
        GetOrgJson = 100500,
        /// <summary>
        /// 新增组织
        /// </summary>
        [Display(GroupName ="系统设置",Name ="新增组织",Description ="新增组织")]
        AddOrg = 100501,
        /// <summary>
        /// 修改组织
        /// </summary>
        [Display(GroupName ="系统设置",Name ="修改组织",Description ="修改组织")]
        UpdateOrg = 100502,
        /// <summary>
        /// 获取组织
        /// </summary>
        [Display(GroupName ="系统设置",Name ="获取组织",Description ="获取组织")]
        GetOrg =  100503,
        /// <summary>
        /// 获取可用组织架构树形
        /// </summary>
        [Display(GroupName ="系统设置",Name = "获取可用组织架构树形",Description = "获取可用组织架构树形")]
        GetCanUseOrg = 100504,
        #endregion
        #endregion

        #region 通话相关接口（200）

        /// <summary>
        /// 电话记录
        /// </summary>
        [Display(GroupName = "电话记录",Name ="电话记录",Description ="电话记录")]
        CallManager = 200000,

        #region 通话记录

        /// <summary>
        /// 分页通话记录列表
        /// </summary>
        [Display(GroupName = "通话", Name = "分页通话记录列表", Description = "分页通话记录列表")]
        GetCallList = 200100,

        #endregion


        #region 黑名单管理

        /// <summary>
        /// 分页查询黑名单
        /// </summary>
        [Display(GroupName = "黑名单管理", Name = "分页查询黑名单", Description = "分页查询黑名单")]
        QueryPagedBlack = 200200,
        /// <summary>
        /// 添加电话号至黑名单
        /// </summary>
        [Display(GroupName = "黑名单管理", Name = "添加电话号至黑名单", Description = "添加电话号至黑名单")]
        AddBlackList = 200201,
        /// <summary>
        /// 删除黑名单数据
        /// </summary>
        [Display(GroupName = "黑名单管理", Name = "删除黑名单数据", Description = "删除黑名单数据")]
        RemoveBlacklist = 200202,

        #endregion


        #endregion

        #region 设备管理（300）
        /// <summary>
        /// 设备管理
        /// </summary>
        [Display(GroupName ="设备管理",Name ="设备管理",Description ="设备管理")]
        DeviceManager = 300000,

        #region 话机
        /// <summary>
        /// 查询所有话机
        /// </summary>
        [Display(GroupName = "话机管理", Name = "查询所有话机", Description = "查询所有话机")]
        QueryTels = 300100,
        /// <summary>
        /// 同步分机
        /// </summary>
        [Display(GroupName ="话机管理",Name ="同步分机",Description ="同步分机")]
        SyncTelsAsync =300101,
        #endregion

        #region 分机组
        /// <summary>
        /// 查询所有分机组
        /// </summary>
        [Display(GroupName = "分机组管理", Name = "查询所有分机组", Description = "查询所有分机组")]
        QueryTelGroups = 300200,
        /// <summary>
        /// 页面基础信息
        /// </summary>
        [Display(GroupName = "分机组管理",Name ="页面基础信息",Description ="页面基础信息")]
        GetBaseInfoGroup = 300201,
        /// <summary>
        /// 新增分机组
        /// </summary>
        [Display(GroupName = "分机组管理", Name = "新增分机组", Description = "新增分机组")]
        AddTelGroup = 300202,
        /// <summary>
        /// 更新分机组
        /// </summary>
        [Display(GroupName = "分机组管理", Name = "更新分机组", Description = "更新分机组")]
        UpdateTelGroup = 300203,
        #endregion

        #region IVR管理
        #region IVR分类
        /// <summary>
        /// 查询所有IVR分类
        /// </summary>
        [Display(GroupName = "IVR管理", Name = "查询所有IVR分类", Description = "查询所有IVR分类")]
        GetCategories = 300300,
        /// <summary>
        /// 查询IVR分类
        /// </summary>
        [Display(GroupName = "IVR管理", Name = "查询IVR分类（含ivr）", Description = "查询IVR分类（含ivr）")]
        GetCategorie = 300301,
        /// <summary>
        /// 新增IVR分类
        /// </summary>
        [Display(GroupName = "IVR管理", Name = "新增IVR分类", Description = "新增IVR分类")]
        AddCategory = 300302,
        /// <summary>
        /// 更新IVR分类
        /// </summary>
        [Display(GroupName = "IVR管理", Name = "更新IVR分类", Description = "更新IVR分类")]
        UpdateCategory = 300303,
        /// <summary>
        /// 删除分类（包含分类下的IVR）
        /// </summary>
        [Display(GroupName = "IVR管理", Name = "删除分类", Description = "删除分类")]
        RemoveCategory = 300304,
        #endregion

        #region IVR
        /// <summary>
        /// 查询所有IVR
        /// </summary>
        [Display(GroupName = "IVR管理", Name = "查询所有IVR", Description = "查询所有IVR")]
        QueryIvrs = 300400,
        /// <summary>
        /// 新增IVR
        /// </summary>
        [Display(GroupName = "IVR管理", Name = "新增IVR", Description = "新增IVR")]
        AddIvr = 300401,
        /// <summary>
        /// 更新IVR
        /// </summary>
        [Display(GroupName = "IVR管理", Name = "更新IVR", Description = "更新IVR")]
        UpdateIvr = 300402,
        /// <summary>
        /// 构建IVR关系
        /// </summary>
        [Display(GroupName = "IVR管理", Name = "构建IVR关系", Description = "构建IVR关系")]
        Structure = 300403,
        /// <summary>
        /// 删除IVR关系（并非删除IVR）
        /// </summary>
        [Display(GroupName = "IVR管理", Name = "删除IVR关系", Description = "删除IVR关系")]
        DeStructureIvr = 300404,
        /// <summary>
        /// 替换某个IVR分组下的起始IVR
        /// </summary>
        [Display(GroupName = "IVR管理", Name = "替换某个IVR分组下的起始IVR", Description = "替换某个IVR分组下的起始IVR")]
        ReplaceRoot = 300405,
        /// <summary>
        /// 查询ivr分类，以树形结构返回IVR关系
        /// </summary>
        [Display(GroupName = "IVR管理", Name = "查询ivr分类，以树形结构返回IVR关系", Description = "查询ivr分类，以树形结构返回IVR关系")]
        GetBeginingIvr = 300406,
        /// <summary>
        /// 页面基础信息
        /// </summary>
        [Display(GroupName = "IVR管理", Name = "页面基础信息", Description = "页面基础信息")]
        GetBaseInfoIvr = 300407,
        #endregion
        #endregion

        #endregion

        #region 公用（999）
        #region 上/下班
        /// <summary>
        /// 上班
        /// </summary>
        [Display(GroupName = "公用", Name = "上班", Description = "上班")]
        OnDuty = 999101,
        /// <summary>
        /// 下班
        /// </summary>
        [Display(GroupName = "公用", Name = "下班", Description = "下班")]
        OffDuty = 999102,
        #endregion
        #region 通话控制
        /// <summary>
        /// 分机休息
        /// </summary>
        [Display(GroupName = "公用", Name = "分机休息", Description = "分机休息")]
        Rest = 999103,
        /// <summary>
        /// 分机结束休息
        /// </summary>
        [Display(GroupName = "公用", Name = "分机结束休息", Description = "分机结束休息")]
        UnRest = 999104,
        /// <summary>
        /// 保持通话
        /// </summary>
        [Display(GroupName = "公用", Name = "保持通话", Description = "保持通话")]
        Hold = 999105,
        /// <summary>
        /// 恢复状态（接触Hold状态）
        /// </summary>
        [Display(GroupName = "公用", Name = "恢复通话（解除Hold状态）", Description = "恢复通话（解除Hold状态）")]
        UnHold = 999106,
        /// <summary>
        /// 分机呼分机
        /// </summary>
        [Display(GroupName = "公用", Name = "分机呼分机", Description = "分机呼分机")]
        TelToTel = 999107,
        /// <summary>
        /// 分机拨打外部电话
        /// </summary>
        [Display(GroupName = "公用", Name = "分机拨打外部电话", Description = "分机拨打外部电话")]
        TelToOuter = 999108,
        /// <summary>
        /// 指定模拟外线外呼（分机拨打外部电话）
        /// </summary>
        [Display(GroupName = "公用", Name = "指定模拟外线外呼（分机拨打外部电话）", Description = "指定模拟外线外呼（分机拨打外部电话）")]
        TelToOuterByLine = 999109,
        /// <summary>
        /// 来电转分机
        /// </summary>
        [Display(GroupName = "公用", Name = "来电转分机", Description = "来电转分机")]
        VisitorToTel = 999110,
        /// <summary>
        /// 来电转外部电话
        /// </summary>
        [Display(GroupName = "公用", Name = "来电转外部电话", Description = "来电转外部电话")]
        VisitorToOuter = 999111,
        /// <summary>
        /// 来电转分机组队列
        /// </summary>
        [Display(GroupName = "公用", Name = "来电转分机组队列", Description = "来电转分机组队列")]
        VisitorToGroup = 999112,
        /// <summary>
        /// 去电转外部电话
        /// </summary>
        [Display(GroupName = "公用", Name = "去电转外部电话", Description = "去电转外部电话")]
        OuterToOuter = 999113,
        /// <summary>
        /// 去电转分机
        /// </summary>
        [Display(GroupName = "公用", Name = "去电转分机", Description = "去电转分机")]
        OuterToTel = 999114,
        /// <summary>
        /// 三方会议
        /// </summary>
        [Display(GroupName = "公用", Name = "三方会议", Description = "三方会议")]
        Conference = 999115,
        #endregion
        #region 语音文件
        /// <summary>
        /// 查询语音文件
        /// </summary>
        [Display(GroupName = "公用", Name = "查询语音文件", Description = "查询语音文件")]
        VoiceQueryList = 999116,
        /// <summary>
        /// 删除语音文件
        /// </summary>
        [Display(GroupName = "公用", Name = "删除语音文件", Description = "删除语音文件")]
        RemoveVoiceFile = 999117,
        #endregion
        #region 通话
        /// <summary>
        /// 强拆分机
        /// </summary>
        [Display(GroupName = "公用", Name = "强拆分机", Description = "强拆分机")]
        ClearExt = 999118,
        /// <summary>
        /// 强拆来电
        /// </summary>
        [Display(GroupName = "公用", Name = "强拆来电", Description = "强拆来电")]
        ClearVisitor = 999119,
        /// <summary>
        /// 强拆去电
        /// </summary>
        [Display(GroupName = "公用", Name = "强拆去电", Description = "强拆去电")]
        ClearOuter = 999120,
        ///// <summary>
        ///// 通话记录（外部对接）
        ///// </summary>
        //[Display(GroupName = "通话", Name = "通话记录（外部对接）", Description = "通话记录（外部对接）")]
        //GetOutCallList = 999121,
        /// <summary>
        /// 监听分机
        /// </summary>
        [Display(GroupName = "公用", Name = "监听分机", Description = "监听分机")]
        MonitorExt = 999121,
        /// <summary>
        /// 从监听到插播状态变换
        /// </summary>
        [Display(GroupName = "公用", Name = "从监听到插播状态变换", Description = "从监听到插播状态变换")]
        MonitorExtToTalk = 999122,
        /// <summary>
        /// 从插播到监听状态变换
        /// </summary>
        [Display(GroupName = "公用", Name = "从插播到监听状态变换", Description = "从插播到监听状态变换")]
        MonitorExtToListen = 999123,
        /// <summary>
        /// 强插
        /// </summary>
        [Display(GroupName = "公用", Name = "强插", Description = "强插")]
        BargeinExt = 999124,

        #endregion
        #region 话机操作面板权限

        /// <summary>
        /// 坐席面板
        /// </summary>
        [Display(GroupName = "公用",Name ="坐席面板",Description ="坐席面板")]
        TelPanel = 999125,

        #endregion
        #endregion
    }
}